from datetime import datetime

__author__ = 'zirony'


def takendate(tags):
    if ('EXIF DateTimeOriginal' in tags) and (0 < len(tags['EXIF DateTimeOriginal'].values)):
        taken = tags['EXIF DateTimeOriginal'].values
    elif ('EXIF DateTimeDigitized' in tags) and (0 < len(tags['EXIF DateTimeDigitized'].values)):
        taken = tags['EXIF DateTimeDigitized'].values
    elif ('Image DateTime' in tags) and (0 < len(tags['Image DateTime'].values)):
        taken = tags['Image DateTime'].values
    else:
        return False

    return datetime.strptime(taken, '%Y:%m:%d %H:%M:%S')



from unittest import TestCase

import usexif


class TestStrange(TestCase):
    def test_strange_1(self):
        ret = usexif.fromfile('test/asset/tag_without_ref.jpg')
        self.assertTrue(ret['latitude'] > 0)
        self.assertTrue(ret['longitude'] > 0)
        self.assertTrue(ret['altitude'] > 0)



import exifread
import usexif
from datetime import datetime
from unittest import TestCase


class TestExif(TestCase):
    def setUp(self):
        with open('test/asset/tag.jpg', 'rb') as f:
            self._tags = exifread.process_file(f)

    def test_latitude(self):
        latitude = usexif.geo.latitude(self._tags)
        self.assertTrue(bool(latitude))
        self.assertTrue(0 < latitude)

        self._tags['GPS GPSLatitudeRef'].values = 'S'
        latitude = usexif.geo.latitude(self._tags)
        self.assertTrue(0 > latitude)

    def test_longitude(self):
        longitude = usexif.geo.longitude(self._tags)
        self.assertTrue(bool(longitude))
        self.assertTrue(0 < longitude)

        self._tags['GPS GPSLongitudeRef'].values = 'W'
        longitude = usexif.geo.longitude(self._tags)
        self.assertTrue(0 > longitude)

    def test_altitude(self):
        altitude = usexif.geo.altitude(self._tags)
        self.assertTrue(bool(altitude))

    def test_date(self):
        taken = usexif.date.takendate(self._tags)
        self.assertEqual(datetime(2016, 4, 18, 10, 41, 6), taken)



import usexif
from unittest import TestCase
from datetime import datetime


class TestDoit(TestCase):
    def test_class(self):
        r = usexif.fromfile('test/asset/tag.jpg')
        self.assertEqual(float, type(r['latitude']))
        self.assertTrue(r['latitude'] > 0)
        self.assertEqual(float, type(r['longitude']))
        self.assertTrue(r['longitude'] > 0)
        self.assertEqual(float, type(r['altitude']))
        self.assertTrue(r['altitude'] > 0)
        self.assertEqual(datetime, type(r['taken_date']))
        self.assertTrue(r['taken_date'] > datetime(2016, 1, 1))
        self.assertEqual(dict, type(r['tags']))
        self.assertTrue(r['tags'])

    def test_notag(self):
        r = usexif.fromfile('test/asset/notag.jpg')
        self.assertEqual(bool, type(r['latitude']))
        self.assertEqual(bool, type(r['longitude']))
        self.assertEqual(0, r['altitude'])
        self.assertEqual(bool, type(r['taken_date']))
        self.assertEqual(dict, type(r['tags']))
        self.assertFalse(r['tags'])




__author__ = 'zirony'


def _ratio2float(ratio):
    return float(ratio.num / ratio.den)


def latitude(tags):
    if 'GPS GPSLatitude' not in tags:
        return False

    neg = False
    if 'GPS GPSLatitudeRef' in tags:
        ref = str(tags['GPS GPSLatitudeRef'].values)
        neg = (ref == 'S')

    lat = _ratio2float(tags['GPS GPSLatitude'].values[0])
    lat += _ratio2float(tags['GPS GPSLatitude'].values[1]) / 60
    lat += _ratio2float(tags['GPS GPSLatitude'].values[2]) / 3600
    return -lat if neg else lat


def longitude(tags):
    if 'GPS GPSLongitude' not in tags:
        return False

    neg = False
    if 'GPS GPSLongitudeRef' in tags:
        ref = tags['GPS GPSLongitudeRef'].values
        neg = (ref == 'W')

    long = _ratio2float(tags['GPS GPSLongitude'].values[0])
    long += _ratio2float(tags['GPS GPSLongitude'].values[1]) / 60
    long += _ratio2float(tags['GPS GPSLongitude'].values[2]) / 3600
    return -long if neg else long


def altitude(tags):
    if 'GPS GPSAltitude' not in tags:
        return False

    neg = False
    if 'GPS GPSAltitudeRef' in tags:
        ref = tags['GPS GPSAltitudeRef'].values
        neg = (ref == 1)

    alt = _ratio2float(tags['GPS GPSAltitude'].values[0])
    return -alt if neg else alt



from setuptools import setup
import pypandoc
import os


readme_path = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'README.md')
long_desc = pypandoc.convert('README.md', 'rst')
version = '1.0.2'

setup(
    name='usexif',
    packages=['usexif'],
    version=version,
    description='get geo data and taken date',
    long_description=long_desc,
    author='Juncheol Cho',
    author_email='zironycho@gmail.com',
    url='https://github.com/zironycho/usexif',
    download_url='https://github.com/zironycho/usexif/tarball/{}'.format(version),
    keywords=['exif', 'geo', 'taken', 'geo', 'geographic coordinate', 'coordinate'],
    license='MIT',
    classifiers=[],
    install_requires=[
       'exifread'
    ],
)
